// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
*******     BEGIN DATA MANIPULATION OF CHAPTER 3b SIX-OCCASION EXAMPLE   *******
*******               CHANGE "filesave" to your directory                *******
********************************************************************************

// Defining global variable for file location to be replaced in code below
   global filesave "C:\Dropbox\21_PSQF7375_Longitudinal\PSQF7375_Longitudinal_Example3b"

// Import chapter 3 six-occasion stacked data
   use "$filesave\STATA_Chapter3b.dta", clear

********************************************************************************
*******               BEGIN CHAPTER 3b SIX-OCCASION MODELS               *******
********************************************************************************

// Save results to separate file
   log using $filesave\STATA_Chapter3b_Output.log, replace name(STATA_Chapter3b)

display "Chapter 3b Example: Means by session for RT outcome"
tabulate session, summarize(rt)

display "Eq 3.10: Between-Person Independent ANOVA via STATA MIXED"
mixed rt ib(last).session, ///
           || personid: , noconstant variance reml ///
           residuals(independent,t(session)) dfmethod(residual) dftable(pvalue),
      estat ic, n(101),          // Information criteria using level-2 N
      contrast i.session, small  // Omnibus F-test
      margins  i.session         // Means per session  
	  margins  i.session, pwcompare(pveffects) df(101) // Mean differences
      estimates store FitBPANOVA // Save results

display "Eq 3.10: Univariate Repeated Measures ANOVA via STATA MIXED"
mixed rt ib(last).session, ///
           || personid: , noconstant variance reml ///
           residuals(exchangeable,t(session)) dfmethod(satterthwaite) dftable(pvalue),
      estat ic, n(101),               // Information criteria using level-2 N
      estat wcorrelation, covariance  // RCOV matrix
      estat wcorrelation              // RCORR matrix
      contrast i.session, small       // Omnibus F-test
      margins  i.session              // Means per session   
	  margins  i.session, pwcompare(pveffects) df(101) // Mean differences
      estimates store FitUnivANOVA    // Save results
      lrtest FitUnivANOVA FitBPANOVA  // Model comparison

display "Eq 3.10: Multivariate Repeated Measures ANOVA via STATA MIXED"
mixed rt ib(last).session, ///
           || personid: , noconstant variance reml ///
           residuals(unstructured,t(session)) dfmethod(satterthwaite) dftable(pvalue),
      estat ic, n(101),                   // Information criteria using level-2 N
      estat wcorrelation, covariance      // RCOV matrix
      estat wcorrelation                  // RCORR matrix
      contrast i.session, small           // Omnibus F-test
      margins  i.session                  // Means per session 
	  margins  i.session, pwcompare(pveffects) df(101) // Mean differences
      estimates store FitMultivANOVA      // Save results
      lrtest FitMultivANOVA FitUnivANOVA  // Model comparison
 
****** END CHAPTER 3b MODELS ******

// Close log
   log close STATA_Chapter3b

